#
# spec file for package python-openapi-spec-validator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-openapi-spec-validator
Version:        0.7.1
Release:        1.2
Summary:        Python module for validating OpenAPI Specs against Swagger and OAS3
License:        Apache-2.0
URL:            https://github.com/p1c2u/openapi-spec-validator
Source:         https://github.com/p1c2u/openapi-spec-validator/archive/%{version}.tar.gz#/openapi-spec-validator-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-openapi_spec_validator
Requires:       (python-jsonschema >= 4.18 with python-jsonschema < 5)
Requires:       (python-jsonschema-path >= 0.3.1 with python-jsonschema-path < 0.4)
Requires:       (python-lazy-object-proxy >= 1.7.1 with python-lazy-object-proxy < 2)
Requires:       (python-openapi-schema-validator >= 0.6.0 with python-openapi-schema-validator < 0.7)
%if %{python_version_nodots} < 39
Requires:       python-importlib-resources >= 5.8.0
%endif
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module importlib-resources >= 5.8.0 if %python-base < 3.9}
BuildRequires:  %{python_module jsonschema >= 4.18 with %python-jsonschema < 5}
BuildRequires:  %{python_module jsonschema-path >= 0.3.1 with %python-jsonschema-path < 0.4}
BuildRequires:  %{python_module lazy-object-proxy >= 1.7.1 with %python-lazy-object-proxy < 2}
BuildRequires:  %{python_module openapi-schema-validator >= 0.6.0 with %python-openapi-schema-validator < 0.7}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
OpenAPI Spec Validator is a Python library that validates
OpenAPI Specs against the OpenAPI 2.0 (aka Swagger) and
OpenAPI 3.0.0 specification. The validator aims to check
for full compliance with the Specification.

%prep
%autosetup -p1 -n openapi-spec-validator-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/openapi-spec-validator
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative openapi-spec-validator

%postun
%python_uninstall_alternative openapi-spec-validator

%check
sed -i 's:tool.pytest.ini_options:hide:' pyproject.toml
%pytest -m 'not network'

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/openapi-spec-validator
%{python_sitelib}/openapi_spec_validator
%{python_sitelib}/openapi_spec_validator-%{version}.dist-info

%changelog
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  * Move to jsonschema-path package #292
  * Validator accepts any schema (schema dictionary or
    SchemaPath) #293
  * `validate` and `validate_url` shortcuts #294
  * `validate_spec` shortcut in deprecated. Use`validate`
    instead.
  * `validate_spec_url` shortcut is deprecated. Use
    `validate_url` instead.
- update to 0.7.0:
  * Allow validate multiple files (also with pre-commit hook)
  * Validators and keywords refactor #286
  * Python 3.12 support #290
  * Bump docker image python from 3.11.5-alpine to 3.12.0-alpine
  * `openapi_*_spec_validator` objects are deprecated. Use
    `*SpecValidator` classes instead.
* Sat Jul 29 2023 Ben Greiner <code@bnavigator.de>
- Update requirements
* Tue Jul 25 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.0:
  * Compatibility with jsonschema 4.18, jsonschema-spec 0.2 and
    openapi-schema-validator 0.6 #202
  * spec_url parameter of spec validator is deprecated. Use base_uri
    instead. #202
  * Drop python 3.7 support #226
  * Update SupportsValidation protocol #232
  * allow path item ref fix #210
  * openapi 3.1 schema update #213
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue May  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.6
  * Fix typo in server variables schema for OpenAPI 3.1.0 #198
  * Include tests in sdist archives #199
  * jsonschema 4.17 dependency limit #203
  * add python 3.11 support #204
- Release 0.5.5
  * update openapi-schema-validator dependecy #194
- Release 0.5.4
  * schema properties validation recursion fix #193
- Release 0.5.3
  * fix custom format checker not found test #190
  * fix property missing reference validation #191
- Release 0.5.2
  * Use stdlib importlib.resources on python >= 3.9 #174
  * mypy typing module version fix #181
  * Drop no longer used runtime dependency on PyYAML #180
  * allow openapi-schema-validator 0.4 #187
* Tue Oct 25 2022 Matej Cepl <mcepl@suse.com>
- Remove conditional definition of python_module.
* Wed Oct  5 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.1:
  * Responses schema validation #177
  * detect spec schema version #167
  * static types and Mypy static type check #168
  * tests mark network #169
  * schemas and validators lazy loading proxy #170
- Drop patch openapi-spec-validator-skip-urls.patch, fixed by upstream
  by markers.
* Mon Mar 28 2022 pgajdos@suse.com
- version update to 0.4.0
  * Drop Python 2.7, 3.5 and 3.6 support #137
  * Add Python 3.10 support #137
  * Bump dependency upper bounds #137
  * Drop pyrsistent direct dependency #142
  * Use valid licence registry identifier for Apache-2.0 licence #139
  * add setuptools dependency for pkg_resources, sort deps #141
  * On validation error: add cause and context. #129
  * Switch to poetry and update dependencies #136
  * File handler Windows compatibility fix (#122)
  * Recurse references in validation (#125)
  * A $ref may be a property name fix (#124)
  * Latest spec 3.0 schema (#110)
  * Switched to using requests rather than direct use of urllib3 (#93)
  * Handlers timeout param fix (#107)
  * Detect duplicate operationId fix (#109)
  * Repair default and $ref issue (#91)
- python-mock is not required for build
- modified patches
  %% openapi-spec-validator-skip-urls.patch (refreshed)
* Mon Dec 21 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.2.9:
  * Added description to setup.py
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.8:
  * no upstream changelog
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.7:
  * Replace pathlib with pathlib2 (#68)
  * Bump PyYAML to 5.1 for CVE-2017-18342 (#69)
  * Support jsonschema 3 (#72)
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Wed Aug  8 2018 tchvatal@suse.com
- Add patch to disable tests that poke live URL:
  * openapi-spec-validator-skip-urls.patch
* Wed Aug  8 2018 tchvatal@suse.com
- Switch to github tarball to run tests
- Fix runtime deps
* Mon Jul 30 2018 sean.marlow@suse.com
- Initial release v0.2.4
